from kwark.command import PromptBasedCommand


class DocCommand(PromptBasedCommand):
    """Summarize observations and conclusions from random text such as a
    thread, email, or notes"""

    name = 'doc'
    success_message = "Generated documentation summary"



from kwark.command import KwarkCommand
from kwark.ai import AI


class ChatCommand(KwarkCommand):
    """Simple chat command to interact with AI.
    Takes input text and returns an AI response."""

    name = 'chat'

    @KwarkCommand.wrap
    def execute(self):
        initial_message = self.app.stream.text.strip() or None

        ai = AI(self.api_key)
        ai.chat(self.app.ui, initial_message=initial_message)

        self.status = "Chat session completed"



from kwark.command import PromptBasedCommand


class CommitCommand(PromptBasedCommand):
    """Generate a git commit message from diff output using AI.
    If there are no changes in the diff, use a dot as the commit message."""

    name = 'commit'
    success_message = "Generated commit message from diff"
